from distutils.core import setup

setup(
        name = 'nestercj',
        version = '1.0.3',
        py_modules = ['nestercj'],
        author = 'codejuro',
        author_email = 'royutsargo@gmail.com',
        url= 'http://www.codejuro.com',
        description = 'A simple printer of nested lists',
    )
